Index: base/mac/scoped_cftyperef.h |
=================================================================== |
--- base/mac/scoped_cftyperef.h (revision 0) |
+++ base/mac/scoped_cftyperef.h (working copy) |
@@ -1,35 +1,39 @@ |
-// Copyright (c) 2006-2008 The Chromium Authors. All rights reserved. |
+// Copyright (c) 2010 The Chromium Authors. All rights reserved. |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef BASE_SCOPED_CFTYPEREF_H_ |
-#define BASE_SCOPED_CFTYPEREF_H_ |
+#ifndef BASE_MAC_SCOPED_CFTYPEREF_H_ |
+#define BASE_MAC_SCOPED_CFTYPEREF_H_ |
#pragma once |
#include <CoreFoundation/CoreFoundation.h> |
+ |
#include "base/basictypes.h" |
#include "base/compiler_specific.h" |
-// scoped_cftyperef<> is patterned after scoped_ptr<>, but maintains ownership |
+namespace base { |
+namespace mac { |
+ |
+// ScopedCFTypeRef<> is patterned after scoped_ptr<>, but maintains ownership |
// of a CoreFoundation object: any object that can be represented as a |
// CFTypeRef. Style deviations here are solely for compatibility with |
// scoped_ptr<>'s interface, with which everyone is already familiar. |
// |
// When scoped_cftyperef<> takes ownership of an object (in the constructor or |
// in reset()), it takes over the caller's existing ownership claim. The |
// caller must own the object it gives to scoped_cftyperef<>, and relinquishes |
// an ownership claim to that object. scoped_cftyperef<> does not call |
// CFRetain(). |
template<typename CFT> |
-class scoped_cftyperef { |
+class ScopedCFTypeRef { |
public: |
typedef CFT element_type; |
- explicit scoped_cftyperef(CFT object = NULL) |
+ explicit ScopedCFTypeRef(CFT object = NULL) |
: object_(object) { |
} |
- ~scoped_cftyperef() { |
+ ~ScopedCFTypeRef() { |
if (object_) |
CFRelease(object_); |
} |
@@ -74,7 +78,10 @@ |
private: |
CFT object_; |
- DISALLOW_COPY_AND_ASSIGN(scoped_cftyperef); |
+ DISALLOW_COPY_AND_ASSIGN(ScopedCFTypeRef); |
}; |
-#endif // BASE_SCOPED_CFTYPEREF_H_ |
+} // namespace mac |
+} // namespace base |
+ |
+#endif // BASE_MAC_SCOPED_CFTYPEREF_H_ |
@@ -1,35 +1,39 @@ |
// scoped_ptr<>'s interface, with which everyone is already familiar. |
// |
-// When scoped_cftyperef<> takes ownership of an object (in the constructor or |
+// When ScopedCFTypeRef<> takes ownership of an object (in the constructor or |
// in reset()), it takes over the caller's existing ownership claim. The |
@@ -1,35 +1,39 @@ |
// in reset()), it takes over the caller's existing ownership claim. The |
-// caller must own the object it gives to scoped_cftyperef<>, and relinquishes |
-// an ownership claim to that object. scoped_cftyperef<> does not call |
+// caller must own the object it gives to ScopedCFTypeRef<>, and relinquishes |
+// an ownership claim to that object. ScopedCFTypeRef<> does not call |
// CFRetain(). |
template<typename CFT> |